print("import: 'kubernetes'")
import kubernetes

print("import: 'kubernetes.client'")
import kubernetes.client

print("import: 'kubernetes.client.api'")
import kubernetes.client.api

print("import: 'kubernetes.client.apis'")
import kubernetes.client.apis

print("import: 'kubernetes.client.models'")
import kubernetes.client.models

print("import: 'kubernetes.config'")
import kubernetes.config

print("import: 'kubernetes.watch'")
import kubernetes.watch

print("import: 'kubernetes.utils'")
import kubernetes.utils

